@@ -37,7 +37,7 @@
 # define C_INSTALL_CC "gcc"
 #endif
 #ifndef C_INSTALL_CXX
-# define C_INSTALL_CXX "g++"
+# define C_INSTALL_CXX "c++"
 #endif
 #ifndef C_INSTALL_POSTINSTALL_PROGRAM
 # define C_INSTALL_POSTINSTALL_PROGRAM "true"
@@ -46,10 +46,10 @@
 # define C_INSTALL_RC_COMPILER ""
 #endif
 #ifndef C_INSTALL_CFLAGS
-# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2 -D_FORTIFY_SOURCE=2 -I/usr/pkg/include"
+# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2  -I/usr/pkg/include"
 #endif
 #ifndef C_INSTALL_LDFLAGS
-# define C_INSTALL_LDFLAGS "-Wl,-zrelro -Wl,-R/usr/pkg/lib "
+# define C_INSTALL_LDFLAGS "-Wl,-R/usr/pkg/lib "
 #endif
 #ifndef C_INSTALL_PREFIX
 # define C_INSTALL_PREFIX "/usr/pkg"
@@ -94,7 +94,7 @@
 # define C_TARGET_CC "gcc"
 #endif
 #ifndef C_TARGET_CXX
-# define C_TARGET_CXX "g++"
+# define C_TARGET_CXX "c++"
 #endif
 #ifndef C_TARGET_RC_COMPILER
 # define C_TARGET_RC_COMPILER ""
@@ -106,13 +106,13 @@
 # define C_TARGET_INSTALL_PROGRAM "/usr/bin/install"
 #endif
 #ifndef C_TARGET_CFLAGS
-# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2 -D_FORTIFY_SOURCE=2 -I/usr/pkg/include"
+# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -O2  -I/usr/pkg/include"
 #endif
 #ifndef C_TARGET_LIBRARIAN_FLAGS
 # define C_TARGET_LIBRARIAN_FLAGS "cru"
 #endif
 #ifndef C_TARGET_LDFLAGS
-# define C_TARGET_LDFLAGS "-Wl,-zrelro -Wl,-R/usr/pkg/lib "
+# define C_TARGET_LDFLAGS "-Wl,-R/usr/pkg/lib "
 #endif
 #ifndef C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS
 # define C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS "-m 755"
